@@ -33,6 +33,9 @@ import ConfigParser
 
 from xml.dom import minidom, Node
 
+#Connect to osso service
+ctx = osso.Context('fSchedule', '0.1', False)
+
 gtk.gdk.threads_init()
 
 class MovieWindow(hildon.StackableWindow):
@@ -276,7 +279,7 @@ class Window(hildon.StackableWindow):
         banner = hildon.hildon_banner_show_information(self.win, "None", "Downloading Movie details")
 
     def open_url(self, button, data):
-        ctx = osso.Context('fSchedule', '0.1', False)
+        #ctx = osso.Context('fSchedule', '0.1', False)
         osso_rpc = osso.Rpc(ctx)
         osso_rpc.rpc_run("com.nokia.osso_browser","/com/nokia/osso_browser/request", 'com.nokia.osso_browser','load_url',rpc_args=(str(data),))
 
@@ -600,14 +603,13 @@ class MainWindow(hildon.StackableWindow):
         self.show_all()
                    
 	def open_url(self, data):
-		ctx = osso.Context('fSchedule', '0.1', False)
 		osso_rpc = osso.Rpc(ctx)
 		osso_rpc.rpc_run("com.nokia.osso_browser","/com/nokia/osso_browser/request", 'com.nokia.osso_browser','load_url',rpc_args=('http://www.forum.nokia.com/',))
 
     def read_config(self):
         config = ConfigParser.SafeConfigParser()
         try:
-            config.read('fSchedule.default')        
+            config.read('/home/user/.fSchedule')        
             self.defaultsite = int(config.get('default', 'defaultsite'))
         except Exception:
             self.defaultsite = 0
@@ -615,17 +617,17 @@ class MainWindow(hildon.StackableWindow):
     def write_config(self):
         try:
             config = ConfigParser.SafeConfigParser()
-            config.read('fSchedule.default')
+            config.read('~/.fSchedule')
             config.set('default', 'defaultsite', str(self.defaultsite))
             # Writing our configuration file to 'example.cfg'
-            config.write(open('fSchedule.default', 'w'))
+            config.write(open('/home/user/.fSchedule', 'w'))
         except Exception:
             #If there is no config file
             config_raw = ConfigParser.RawConfigParser()
             config_raw.add_section('default')
             config_raw.set('default', 'defaultsite', str(self.defaultsite))
-            #Writing our new configuration to file 'fSchedule.default'
-            config_raw.write(open('fSchedule.default', 'wb'))        
+            #Writing our new configuration to file '/home/user/.fSchedule'
+            config_raw.write(open('/home/user/.fSchedule', 'wb'))        
         
 class fSchedule(hildon.Program):
 	def __init__(self):
